#!/usr/bin/env gnuplot

reset
set grid
set xlabel "Cu-Cl distance (bohr)"
set ylabel "CCSD(T) energy (au)"
set format y "%.2f"

a0 = 1.8897161646321
E(r) = De * (1-exp(-a*(r-re)))**2 + E0

a               = 0.84615   #      +/- 0.03216      (3.8%)
re              = 3.92539   #      +/- 0.01058      (0.2696%)
De              = 0.101589  #      +/- 0.00932      (9.174%)
E0              = -2099.77  #      +/- 0.0008014    (3.817e-05%)

set xrange [2.7:5.2]
fit  E(x) 'cucl.dat' using ($1*a0):3:4 via  a, re, De, E0

set xrange [3:5.2]
set term pdfcairo enhanced font "Times,14" linewidth 2 rounded size 5.0in, 3.0in
set output 'cucl.pdf'
set pointsize 0.5
plot \
'cucl.dat' using ($1*a0):2 pointtype 3 lc rgb "red" title "Full (T)", \
E(x) title "" lt 3 lc rgb "grey", \
'cucl.dat' using ($1*a0):3:4 w err pt 0 lc rgb "blue"  title "1% (T)"



